Description Usage Arguments Details Value Note Author(s) Examples
readBenc reads content in Bencoding into R objects.
1 | readBenc(what)
|
what |
character string of file name(s), binary connection or a raw vector |
Bencoding defines integers, strings, lists and dictionaries which are stored as integer (or real) scalars, string scalars, pairlists and named parilists respectively.
Decoded content. If what is a character vector of more than one
element then the result is a list equivalent to
lapply(what, readBenc).
In principle Bencoding supports integers of arbitary precision, but R only supports signed integers up to 32-bit. All values outsisde that range will be stored as (double-precision) reals. This means that only signed integers up to 53-bit precision will be represented without loss of precision.
R does not allow strings with embedded NULs, so any string with a value less than TAB is returned as a raw vector.
Simon Urbanek
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.